#[non_exhaustive]pub struct AxisSource(pub u32);Expand description
axis source types
Describes the source types for axis events. This indicates to the client how an axis event was physically generated; a client may adjust the user interface accordingly. For example, scroll events from a “finger” source may be in a smooth coordinate space with kinetic scrolling whereas a “wheel” source may be in discrete steps of a number of lines.
The “continuous” axis source is a device generating events in a continuous coordinate space, but using something other than a finger. One example for this source is button-based scrolling where the vertical motion of a device is converted to scroll events while a button is held down.
The “wheel tilt” axis source indicates that the actual device is a wheel but the scroll event is not caused by a rotation but a (usually sideways) tilt of the wheel.
Tuple Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.0: u32Implementations
Sourceimpl AxisSource
impl AxisSource
Sourceimpl AxisSource
impl AxisSource
Sourcepub fn available_since(self) -> Option<u32>
pub fn available_since(self) -> Option<u32>
First protocol version enum variant is avilable in
None for unrecognized value.